Module flutter_rust_bridge::handler
source · Structs
- The default one.
- The default executor used. It creates an internal thread pool, and each call to a Rust function is handled by a different thread.
- The simple handler uses a simple thread pool to execute tasks.
- A context for task execution
- Supporting information for a task
Enums
- The types of return values for a particular Rust function.
- Errors that occur from normal code execution.
Traits
- Listens when error happens
- An executor model for Rust functions.